import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'icon_forest.dart';

/// Iconoir icons (30 icons)
///
/// - build svg for iconoir icon libraries
/// - constants link to svg icon resources
class Iconoir extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const Iconoir(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return IconForest.svgAsset(
      'iconoir',
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String $1st_medal = '1st_medal.svg';
  static const String $2x2_cell = '2x2_cell.svg';
  static const String $360_view = '360_view.svg';
  static const String $3d_add_hole = '3d_add_hole.svg';
  static const String $3d_arc_center_pt = '3d_arc_center_pt.svg';
  static const String $3d_arc = '3d_arc.svg';
  static const String $3d_bridge = '3d_bridge.svg';
  static const String $3d_center_box = '3d_center_box.svg';
  static const String $3d_ellipse_three_pts = '3d_ellipse_three_pts.svg';
  static const String $3d_ellipse = '3d_ellipse.svg';
  static const String $3d_pt_box = '3d_pt_box.svg';
  static const String $3d_rect_corner_to_corner =
      '3d_rect_corner_to_corner.svg';
  static const String $3d_rect_from_center = '3d_rect_from_center.svg';
  static const String $3d_rect_three_pts = '3d_rect_three_pts.svg';
  static const String $3d_select_edge = '3d_select_edge.svg';
  static const String $3d_select_face = '3d_select_face.svg';
  static const String $3d_select_point = '3d_select_point.svg';
  static const String $3d_select_solid = '3d_select_solid.svg';
  static const String $3d_three_pts_box = '3d_three_pts_box.svg';
  static const String $4k_display = '4k_display.svg';
  static const String accessibility_sign = 'accessibility_sign.svg';
  static const String accessibility_tech = 'accessibility_tech.svg';
  static const String accessibility = 'accessibility.svg';
  static const String activity = 'activity.svg';
  static const String add_circled_outline = 'add_circled_outline.svg';
  static const String add_database_script = 'add_database_script.svg';
  static const String add_folder = 'add_folder.svg';
  static const String add_frame = 'add_frame.svg';
  static const String add_hexagon = 'add_hexagon.svg';
  static const String add_keyframe_alt = 'add_keyframe_alt.svg';
  static const String add_keyframe = 'add_keyframe.svg';
  static const String add_keyframes = 'add_keyframes.svg';
  static const String add_lens = 'add_lens.svg';
  static const String add_media_image = 'add_media_image.svg';
  static const String add_media_video = 'add_media_video.svg';
  static const String add_page = 'add_page.svg';
  static const String add_pin_alt = 'add_pin_alt.svg';
  static const String add_selection = 'add_selection.svg';
  static const String add_square = 'add_square.svg';
  static const String add_to_cart = 'add_to_cart.svg';
  static const String add_user = 'add_user.svg';
  static const String air_conditioner = 'air_conditioner.svg';
  static const String airplane_helix_45deg = 'airplane_helix_45deg.svg';
  static const String airplane_helix = 'airplane_helix.svg';
  static const String airplane_off = 'airplane_off.svg';
  static const String airplane_rotation = 'airplane_rotation.svg';
  static const String airplane = 'airplane.svg';
  static const String airplay = 'airplay.svg';
  static const String alarm = 'alarm.svg';
  static const String album_carousel = 'album_carousel.svg';
  static const String album_list = 'album_list.svg';
  static const String album_open = 'album_open.svg';
  static const String album = 'album.svg';
  static const String align_bottom_box = 'align_bottom_box.svg';
  static const String align_center = 'align_center.svg';
  static const String align_justify = 'align_justify.svg';
  static const String align_left_box = 'align_left_box.svg';
  static const String align_left = 'align_left.svg';
  static const String align_right_box = 'align_right_box.svg';
  static const String align_right = 'align_right.svg';
  static const String align_top_box = 'align_top_box.svg';
  static const String antenna_off = 'antenna_off.svg';
  static const String antenna_signal_rounded = 'antenna_signal_rounded.svg';
  static const String antenna_signal = 'antenna_signal.svg';
  static const String antenna = 'antenna.svg';
  static const String app_notification = 'app_notification.svg';
  static const String app_window = 'app_window.svg';
  static const String apple_half_alt = 'apple_half_alt.svg';
  static const String apple_half = 'apple_half.svg';
  static const String apple_imac_2021_side = 'apple_imac_2021_side.svg';
  static const String apple_imac_2021 = 'apple_imac_2021.svg';
  static const String apple_mac = 'apple_mac.svg';
  static const String apple_swift = 'apple_swift.svg';
  static const String apple_wallet = 'apple_wallet.svg';
  static const String apple = 'apple.svg';
  static const String ar_symbol = 'ar_symbol.svg';
  static const String arcade = 'arcade.svg';
  static const String archery_match = 'archery_match.svg';
  static const String archery = 'archery.svg';
  static const String archive = 'archive.svg';
  static const String area_search = 'area_search.svg';
  static const String arrow_archery = 'arrow_archery.svg';
  static const String arrow_down_circled = 'arrow_down_circled.svg';
  static const String arrow_down = 'arrow_down.svg';
  static const String arrow_left_circled = 'arrow_left_circled.svg';
  static const String arrow_left = 'arrow_left.svg';
  static const String arrow_right_circled = 'arrow_right_circled.svg';
  static const String arrow_right = 'arrow_right.svg';
  static const String arrow_separate_vertical = 'arrow_separate_vertical.svg';
  static const String arrow_separate = 'arrow_separate.svg';
  static const String arrow_union_vertical = 'arrow_union_vertical.svg';
  static const String arrow_union = 'arrow_union.svg';
  static const String arrow_up_circled = 'arrow_up_circled.svg';
  static const String arrow_up = 'arrow_up.svg';
  static const String asana = 'asana.svg';
  static const String atom = 'atom.svg';
  static const String attachment = 'attachment.svg';
  static const String augmented_reality = 'augmented_reality.svg';
  static const String auto_flash = 'auto_flash.svg';
  static const String axes = 'axes.svg';
  static const String backward_15_seconds = 'backward_15_seconds.svg';
  static const String bag = 'bag.svg';
  static const String bank = 'bank.svg';
  static const String barcode = 'barcode.svg';
  static const String basketball_alt = 'basketball_alt.svg';
  static const String basketball_field = 'basketball_field.svg';
  static const String basketball = 'basketball.svg';
  static const String battery_25 = 'battery_25.svg';
  static const String battery_50 = 'battery_50.svg';
  static const String battery_75 = 'battery_75.svg';
  static const String battery_charging = 'battery_charging.svg';
  static const String battery_empty = 'battery_empty.svg';
  static const String battery_full = 'battery_full.svg';
  static const String battery_indicator = 'battery_indicator.svg';
  static const String battery_warning = 'battery_warning.svg';
  static const String bbq = 'bbq.svg';
  static const String beach_bag_big = 'beach_bag_big.svg';
  static const String beach_bag = 'beach_bag.svg';
  static const String behance_squared = 'behance_squared.svg';
  static const String behance = 'behance.svg';
  static const String bell_notification = 'bell_notification.svg';
  static const String bell_off = 'bell_off.svg';
  static const String bell = 'bell.svg';
  static const String bicycle = 'bicycle.svg';
  static const String bin_add = 'bin_add.svg';
  static const String bin_full = 'bin_full.svg';
  static const String bin_half = 'bin_half.svg';
  static const String bin_minus = 'bin_minus.svg';
  static const String bin = 'bin.svg';
  static const String bishop = 'bishop.svg';
  static const String bluetooth_rounded = 'bluetooth_rounded.svg';
  static const String bluetooth = 'bluetooth.svg';
  static const String bold_square_outline = 'bold_square_outline.svg';
  static const String bold = 'bold.svg';
  static const String bonfire = 'bonfire.svg';
  static const String book_stack = 'book_stack.svg';
  static const String book = 'book.svg';
  static const String bookmark_book = 'bookmark_book.svg';
  static const String bookmark_circled = 'bookmark_circled.svg';
  static const String bookmark_empty = 'bookmark_empty.svg';
  static const String border_bl = 'border_bl.svg';
  static const String border_bottom = 'border_bottom.svg';
  static const String border_br = 'border_br.svg';
  static const String border_inner = 'border_inner.svg';
  static const String border_left = 'border_left.svg';
  static const String border_out = 'border_out.svg';
  static const String border_right = 'border_right.svg';
  static const String border_tl = 'border_tl.svg';
  static const String border_top = 'border_top.svg';
  static const String border_tr = 'border_tr.svg';
  static const String bounce_left = 'bounce_left.svg';
  static const String bounce_right = 'bounce_right.svg';
  static const String bowling_ball = 'bowling_ball.svg';
  static const String box_iso = 'box_iso.svg';
  static const String box = 'box.svg';
  static const String boxing_glove = 'boxing_glove.svg';
  static const String brightness_window = 'brightness_window.svg';
  static const String brightness = 'brightness.svg';
  static const String bubble_download = 'bubble_download.svg';
  static const String bubble_error = 'bubble_error.svg';
  static const String bubble_income = 'bubble_income.svg';
  static const String bubble_outcome = 'bubble_outcome.svg';
  static const String bubble_search = 'bubble_search.svg';
  static const String bubble_star = 'bubble_star.svg';
  static const String bubble_upload = 'bubble_upload.svg';
  static const String bubble_warning = 'bubble_warning.svg';
  static const String building = 'building.svg';
  static const String bus_outline = 'bus_outline.svg';
  static const String bus_stop = 'bus_stop.svg';
  static const String cable_rounded = 'cable_rounded.svg';
  static const String calculator = 'calculator.svg';
  static const String calendar = 'calendar.svg';
  static const String camera = 'camera.svg';
  static const String cancel = 'cancel.svg';
  static const String car_outline = 'car_outline.svg';
  static const String carbon = 'carbon.svg';
  static const String card_wallet = 'card_wallet.svg';
  static const String cart_alt = 'cart_alt.svg';
  static const String cart = 'cart.svg';
  static const String cash = 'cash.svg';
  static const String center_align = 'center_align.svg';
  static const String chat_add = 'chat_add.svg';
  static const String chat_bubble_check_1 = 'chat_bubble_check_1.svg';
  static const String chat_bubble_check = 'chat_bubble_check.svg';
  static const String chat_bubble_empty = 'chat_bubble_empty.svg';
  static const String chat_bubble_error = 'chat_bubble_error.svg';
  static const String chat_bubble_question = 'chat_bubble_question.svg';
  static const String chat_bubble_translate = 'chat_bubble_translate.svg';
  static const String chat_bubble_warning = 'chat_bubble_warning.svg';
  static const String chat_bubble = 'chat_bubble.svg';
  static const String chat_lines = 'chat_lines.svg';
  static const String chat_remove = 'chat_remove.svg';
  static const String check_circled_outline = 'check_circled_outline.svg';
  static const String check_window = 'check_window.svg';
  static const String check = 'check.svg';
  static const String chocolate = 'chocolate.svg';
  static const String chromecast_active = 'chromecast_active.svg';
  static const String chromecast = 'chromecast.svg';
  static const String church_alt = 'church_alt.svg';
  static const String church = 'church.svg';
  static const String cinema_old = 'cinema_old.svg';
  static const String circle = 'circle.svg';
  static const String city = 'city.svg';
  static const String clipboard_check = 'clipboard_check.svg';
  static const String clock_outline = 'clock_outline.svg';
  static const String closet = 'closet.svg';
  static const String cloud_book_alt = 'cloud_book_alt.svg';
  static const String cloud_check = 'cloud_check.svg';
  static const String cloud_desync = 'cloud_desync.svg';
  static const String cloud_download = 'cloud_download.svg';
  static const String cloud_error = 'cloud_error.svg';
  static const String cloud_sunny = 'cloud_sunny.svg';
  static const String cloud_sync = 'cloud_sync.svg';
  static const String cloud_upload = 'cloud_upload.svg';
  static const String cloud = 'cloud.svg';
  static const String code_brackets_square = 'code_brackets_square.svg';
  static const String code_brackets = 'code_brackets.svg';
  static const String code = 'code.svg';
  static const String codepen = 'codepen.svg';
  static const String coin = 'coin.svg';
  static const String collage_frame = 'collage_frame.svg';
  static const String collapse = 'collapse.svg';
  static const String color_filter = 'color_filter.svg';
  static const String color_picker_empty = 'color_picker_empty.svg';
  static const String color_picker = 'color_picker.svg';
  static const String combine = 'combine.svg';
  static const String compact_disc = 'compact_disc.svg';
  static const String compass = 'compass.svg';
  static const String compress_lines = 'compress_lines.svg';
  static const String compress = 'compress.svg';
  static const String computer = 'computer.svg';
  static const String consumable = 'consumable.svg';
  static const String control_slider = 'control_slider.svg';
  static const String cookie = 'cookie.svg';
  static const String copy = 'copy.svg';
  static const String copyright = 'copyright.svg';
  static const String corner_bottom_left = 'corner_bottom_left.svg';
  static const String corner_bottom_right = 'corner_bottom_right.svg';
  static const String corner_top_left = 'corner_top_left.svg';
  static const String corner_top_right = 'corner_top_right.svg';
  static const String cpu_warning = 'cpu_warning.svg';
  static const String cpu = 'cpu.svg';
  static const String cracked_egg = 'cracked_egg.svg';
  static const String creative_commons = 'creative_commons.svg';
  static const String credit_card_2 = 'credit_card_2.svg';
  static const String credit_card = 'credit_card.svg';
  static const String crop_rotate_bl = 'crop_rotate_bl.svg';
  static const String crop_rotate_br = 'crop_rotate_br.svg';
  static const String crop_rotate_tl = 'crop_rotate_tl.svg';
  static const String crop_rotate_tr = 'crop_rotate_tr.svg';
  static const String crop = 'crop.svg';
  static const String css3 = 'css3.svg';
  static const String cursor_pointer = 'cursor_pointer.svg';
  static const String cut_alt = 'cut_alt.svg';
  static const String cut = 'cut.svg';
  static const String cycling = 'cycling.svg';
  static const String cylinder = 'cylinder.svg';
  static const String dash_flag = 'dash_flag.svg';
  static const String dashboard_dots = 'dashboard_dots.svg';
  static const String dashboard_speed = 'dashboard_speed.svg';
  static const String dashboard = 'dashboard.svg';
  static const String data_transfer_both = 'data_transfer_both.svg';
  static const String data_transfer_check = 'data_transfer_check.svg';
  static const String data_transfer_down = 'data_transfer_down.svg';
  static const String data_transfer_up = 'data_transfer_up.svg';
  static const String data_transfer_warning = 'data_transfer_warning.svg';
  static const String database_backup = 'database_backup.svg';
  static const String database_export = 'database_export.svg';
  static const String database_monitor = 'database_monitor.svg';
  static const String database_restore = 'database_restore.svg';
  static const String database_rounded = 'database_rounded.svg';
  static const String database_script = 'database_script.svg';
  static const String database_settings = 'database_settings.svg';
  static const String database_star = 'database_star.svg';
  static const String database_stats = 'database_stats.svg';
  static const String db_check = 'db_check.svg';
  static const String db_error = 'db_error.svg';
  static const String db_search = 'db_search.svg';
  static const String db_star = 'db_star.svg';
  static const String db_warning = 'db_warning.svg';
  static const String db = 'db.svg';
  static const String de_compress = 'de_compress.svg';
  static const String delete_circled_outline = 'delete_circled_outline.svg';
  static const String delivery_truck = 'delivery_truck.svg';
  static const String delivery = 'delivery.svg';
  static const String design_pencil = 'design_pencil.svg';
  static const String dialpad = 'dialpad.svg';
  static const String dice_five = 'dice_five.svg';
  static const String dice_four = 'dice_four.svg';
  static const String dice_one = 'dice_one.svg';
  static const String dice_six = 'dice_six.svg';
  static const String dice_three = 'dice_three.svg';
  static const String dice_two = 'dice_two.svg';
  static const String discord = 'discord.svg';
  static const String dishwasher = 'dishwasher.svg';
  static const String divide_selection_1 = 'divide_selection_1.svg';
  static const String divide_selection_2 = 'divide_selection_2.svg';
  static const String doc_search_alt = 'doc_search_alt.svg';
  static const String doc_search = 'doc_search.svg';
  static const String doc_star_alt = 'doc_star_alt.svg';
  static const String doc_star = 'doc_star.svg';
  static const String dollar = 'dollar.svg';
  static const String domotic_issue = 'domotic_issue.svg';
  static const String donate = 'donate.svg';
  static const String double_check = 'double_check.svg';
  static const String down_round_arrow = 'down_round_arrow.svg';
  static const String download_circled_outline = 'download_circled_outline.svg';
  static const String download_data_window = 'download_data_window.svg';
  static const String download_square_outline = 'download_square_outline.svg';
  static const String download = 'download.svg';
  static const String drag_hand_gesture = 'drag_hand_gesture.svg';
  static const String drawer = 'drawer.svg';
  static const String dribbble = 'dribbble.svg';
  static const String droplet_half = 'droplet_half.svg';
  static const String droplet = 'droplet.svg';
  static const String ease_curve_control_points =
      'ease_curve_control_points.svg';
  static const String ease_in_control_point = 'ease_in_control_point.svg';
  static const String ease_in_out = 'ease_in_out.svg';
  static const String ease_in = 'ease_in.svg';
  static const String ease_out_control_point = 'ease_out_control_point.svg';
  static const String ease_out = 'ease_out.svg';
  static const String edit_pencil = 'edit_pencil.svg';
  static const String edit = 'edit.svg';
  static const String egg = 'egg.svg';
  static const String eject = 'eject.svg';
  static const String electronics_chip = 'electronics_chip.svg';
  static const String electronics_transistor = 'electronics_transistor.svg';
  static const String emoji_ball = 'emoji_ball.svg';
  static const String emoji_blink_left = 'emoji_blink_left.svg';
  static const String emoji_blink_right = 'emoji_blink_right.svg';
  static const String emoji_look_bottom = 'emoji_look_bottom.svg';
  static const String emoji_look_left = 'emoji_look_left.svg';
  static const String emoji_look_right = 'emoji_look_right.svg';
  static const String emoji_look_top = 'emoji_look_top.svg';
  static const String emoji_puzzled = 'emoji_puzzled.svg';
  static const String emoji_quite = 'emoji_quite.svg';
  static const String emoji_really = 'emoji_really.svg';
  static const String emoji_sad = 'emoji_sad.svg';
  static const String emoji_satisfied = 'emoji_satisfied.svg';
  static const String emoji_sing_left_note = 'emoji_sing_left_note.svg';
  static const String emoji_sing_left = 'emoji_sing_left.svg';
  static const String emoji_sing_right_note = 'emoji_sing_right_note.svg';
  static const String emoji_sing_right = 'emoji_sing_right.svg';
  static const String emoji_surprise_alt = 'emoji_surprise_alt.svg';
  static const String emoji_surprise = 'emoji_surprise.svg';
  static const String emoji_talking_angry = 'emoji_talking_angry.svg';
  static const String emoji_talking_happy = 'emoji_talking_happy.svg';
  static const String emoji_think_left = 'emoji_think_left.svg';
  static const String emoji_think_right = 'emoji_think_right.svg';
  static const String emoji = 'emoji.svg';
  static const String empty_page = 'empty_page.svg';
  static const String energy_usage_window = 'energy_usage_window.svg';
  static const String enlarge_round_arrow = 'enlarge_round_arrow.svg';
  static const String enlarge = 'enlarge.svg';
  static const String erase = 'erase.svg';
  static const String error_window = 'error_window.svg';
  static const String euro_square = 'euro_square.svg';
  static const String euro = 'euro.svg';
  static const String ev_charge_alt = 'ev_charge_alt.svg';
  static const String ev_charge = 'ev_charge.svg';
  static const String ev_plug_charging = 'ev_plug_charging.svg';
  static const String ev_plug_error = 'ev_plug_error.svg';
  static const String ev_plug = 'ev_plug.svg';
  static const String ev_rounded = 'ev_rounded.svg';
  static const String ev_station = 'ev_station.svg';
  static const String exclude = 'exclude.svg';
  static const String expand_lines = 'expand_lines.svg';
  static const String expand = 'expand.svg';
  static const String eye_alt = 'eye_alt.svg';
  static const String eye_close = 'eye_close.svg';
  static const String eye_empty = 'eye_empty.svg';
  static const String eye_off = 'eye_off.svg';
  static const String face_id = 'face_id.svg';
  static const String facebook_squared = 'facebook_squared.svg';
  static const String facebook = 'facebook.svg';
  static const String facetime = 'facetime.svg';
  static const String farm = 'farm.svg';
  static const String fast_arrow_down_box = 'fast_arrow_down_box.svg';
  static const String fast_arrow_down = 'fast_arrow_down.svg';
  static const String fast_arrow_left_box = 'fast_arrow_left_box.svg';
  static const String fast_arrow_left = 'fast_arrow_left.svg';
  static const String fast_arrow_right_box = 'fast_arrow_right_box.svg';
  static const String fast_arrow_right = 'fast_arrow_right.svg';
  static const String fast_arrow_top = 'fast_arrow_top.svg';
  static const String fast_arrow_up_box = 'fast_arrow_up_box.svg';
  static const String fast_bottom_circle = 'fast_bottom_circle.svg';
  static const String fast_left_circle = 'fast_left_circle.svg';
  static const String fast_right_circle = 'fast_right_circle.svg';
  static const String fast_top_circle = 'fast_top_circle.svg';
  static const String favourite_book = 'favourite_book.svg';
  static const String favourite_window = 'favourite_window.svg';
  static const String female = 'female.svg';
  static const String figma = 'figma.svg';
  static const String file_not_found = 'file_not_found.svg';
  static const String filter_alt = 'filter_alt.svg';
  static const String filter = 'filter.svg';
  static const String finder = 'finder.svg';
  static const String finger_print_window = 'finger_print_window.svg';
  static const String fingerprint_circled_error =
      'fingerprint_circled_error.svg';
  static const String fingerprint_circled_lock = 'fingerprint_circled_lock.svg';
  static const String fingerprint_circled_ok = 'fingerprint_circled_ok.svg';
  static const String fingerprint_circled = 'fingerprint_circled.svg';
  static const String fingerprint_phone = 'fingerprint_phone.svg';
  static const String fingerprint_scan = 'fingerprint_scan.svg';
  static const String fingerprint_squared = 'fingerprint_squared.svg';
  static const String fingerprint = 'fingerprint.svg';
  static const String fire_flame = 'fire_flame.svg';
  static const String fishing = 'fishing.svg';
  static const String flare = 'flare.svg';
  static const String flash_off = 'flash_off.svg';
  static const String flash = 'flash.svg';
  static const String flask = 'flask.svg';
  static const String flip_reverse = 'flip_reverse.svg';
  static const String flip = 'flip.svg';
  static const String flower = 'flower.svg';
  static const String fluorine = 'fluorine.svg';
  static const String fog = 'fog.svg';
  static const String folder_alert = 'folder_alert.svg';
  static const String folder = 'folder.svg';
  static const String font_size = 'font_size.svg';
  static const String football_ball = 'football_ball.svg';
  static const String football = 'football.svg';
  static const String forward_15_seconds = 'forward_15_seconds.svg';
  static const String forward_outline = 'forward_outline.svg';
  static const String frame_alt_empty = 'frame_alt_empty.svg';
  static const String frame_alt = 'frame_alt.svg';
  static const String frame_select = 'frame_select.svg';
  static const String frame_simple = 'frame_simple.svg';
  static const String frame_tool = 'frame_tool.svg';
  static const String frame = 'frame.svg';
  static const String fridge = 'fridge.svg';
  static const String fx_rounded = 'fx_rounded.svg';
  static const String fx = 'fx.svg';
  static const String gamepad = 'gamepad.svg';
  static const String garage = 'garage.svg';
  static const String gas_tank_drop = 'gas_tank_drop.svg';
  static const String gas_tank = 'gas_tank.svg';
  static const String gas = 'gas.svg';
  static const String gift = 'gift.svg';
  static const String git_branch = 'git_branch.svg';
  static const String git_commit = 'git_commit.svg';
  static const String git_merge = 'git_merge.svg';
  static const String github_outline = 'github_outline.svg';
  static const String github = 'github.svg';
  static const String gitlab_full = 'gitlab_full.svg';
  static const String glass_empty = 'glass_empty.svg';
  static const String glass_half_alt = 'glass_half_alt.svg';
  static const String glass_half = 'glass_half.svg';
  static const String glasses = 'glasses.svg';
  static const String globe = 'globe.svg';
  static const String golf = 'golf.svg';
  static const String google_circled = 'google_circled.svg';
  static const String google_docs = 'google_docs.svg';
  static const String google_drive_check = 'google_drive_check.svg';
  static const String google_drive_sync = 'google_drive_sync.svg';
  static const String google_drive_warning = 'google_drive_warning.svg';
  static const String google_drive = 'google_drive.svg';
  static const String google_home = 'google_home.svg';
  static const String google_one = 'google_one.svg';
  static const String google = 'google.svg';
  static const String gps = 'gps.svg';
  static const String graph_down = 'graph_down.svg';
  static const String graph_up = 'graph_up.svg';
  static const String grid_add = 'grid_add.svg';
  static const String grid_minus = 'grid_minus.svg';
  static const String grid_remove = 'grid_remove.svg';
  static const String group = 'group.svg';
  static const String gym = 'gym.svg';
  static const String half_cookie = 'half_cookie.svg';
  static const String half_moon = 'half_moon.svg';
  static const String hand_brake = 'hand_brake.svg';
  static const String handbag = 'handbag.svg';
  static const String hard_drive = 'hard_drive.svg';
  static const String hat = 'hat.svg';
  static const String hd_display = 'hd_display.svg';
  static const String hd = 'hd.svg';
  static const String hdr = 'hdr.svg';
  static const String headset_charge = 'headset_charge.svg';
  static const String headset_help = 'headset_help.svg';
  static const String headset_issue = 'headset_issue.svg';
  static const String headset = 'headset.svg';
  static const String health_shield = 'health_shield.svg';
  static const String healthcare = 'healthcare.svg';
  static const String heart = 'heart.svg';
  static const String heavy_rain = 'heavy_rain.svg';
  static const String heptagon = 'heptagon.svg';
  static const String her_slips = 'her_slips.svg';
  static const String hesa_warning_outline = 'hesa_warning_outline.svg';
  static const String hexagon_alt = 'hexagon_alt.svg';
  static const String hexagon_dice = 'hexagon_dice.svg';
  static const String hexagon = 'hexagon.svg';
  static const String high_priority = 'high_priority.svg';
  static const String historic_shield_alt = 'historic_shield_alt.svg';
  static const String historic_shield = 'historic_shield.svg';
  static const String home_alt_slim_horiz = 'home_alt_slim_horiz.svg';
  static const String home_alt_slim = 'home_alt_slim.svg';
  static const String home_alt = 'home_alt.svg';
  static const String home_hospital = 'home_hospital.svg';
  static const String home_simple_door = 'home_simple_door.svg';
  static const String home_simple = 'home_simple.svg';
  static const String home_user = 'home_user.svg';
  static const String home = 'home.svg';
  static const String horiz_distribution_left = 'horiz_distribution_left.svg';
  static const String horiz_distribution_right = 'horiz_distribution_right.svg';
  static const String hospital_sign = 'hospital_sign.svg';
  static const String hospital = 'hospital.svg';
  static const String hourglass = 'hourglass.svg';
  static const String html5 = 'html5.svg';
  static const String hydrogen = 'hydrogen.svg';
  static const String iconoir = 'iconoir.svg';
  static const String import = 'import.svg';
  static const String industry = 'industry.svg';
  static const String info_empty = 'info_empty.svg';
  static const String input_field = 'input_field.svg';
  static const String input_search = 'input_search.svg';
  static const String instagram = 'instagram.svg';
  static const String internet = 'internet.svg';
  static const String intersect_alt = 'intersect_alt.svg';
  static const String intersect = 'intersect.svg';
  static const String ios_settings = 'ios_settings.svg';
  static const String ip_address = 'ip_address.svg';
  static const String iris_scan = 'iris_scan.svg';
  static const String italic_square_outline = 'italic_square_outline.svg';
  static const String italic = 'italic.svg';
  static const String journal_page = 'journal_page.svg';
  static const String journal = 'journal.svg';
  static const String kanban_board = 'kanban_board.svg';
  static const String key_alt_back = 'key_alt_back.svg';
  static const String key_alt_minus = 'key_alt_minus.svg';
  static const String key_alt_plus = 'key_alt_plus.svg';
  static const String key_alt_remove = 'key_alt_remove.svg';
  static const String key_alt = 'key_alt.svg';
  static const String keyframe_align_center = 'keyframe_align_center.svg';
  static const String keyframe_align_horizontal =
      'keyframe_align_horizontal.svg';
  static const String keyframe_align_vertical = 'keyframe_align_vertical.svg';
  static const String keyframe_position = 'keyframe_position.svg';
  static const String keyframe = 'keyframe.svg';
  static const String keyframes_couple = 'keyframes_couple.svg';
  static const String keyframes = 'keyframes.svg';
  static const String label_outline = 'label_outline.svg';
  static const String lamp = 'lamp.svg';
  static const String language = 'language.svg';
  static const String laptop_charging = 'laptop_charging.svg';
  static const String laptop_fix = 'laptop_fix.svg';
  static const String laptop_issue = 'laptop_issue.svg';
  static const String laptop = 'laptop.svg';
  static const String large_suitcase = 'large_suitcase.svg';
  static const String layout_left = 'layout_left.svg';
  static const String layout_right = 'layout_right.svg';
  static const String leaderboard_star = 'leaderboard_star.svg';
  static const String leaderboard = 'leaderboard.svg';
  static const String left_round_arrow = 'left_round_arrow.svg';
  static const String lens = 'lens.svg';
  static const String lifebelt = 'lifebelt.svg';
  static const String light_bulb_off = 'light_bulb_off.svg';
  static const String light_bulb_on = 'light_bulb_on.svg';
  static const String light_bulb = 'light_bulb.svg';
  static const String line_space = 'line_space.svg';
  static const String linear = 'linear.svg';
  static const String link = 'link.svg';
  static const String linkedin = 'linkedin.svg';
  static const String linux = 'linux.svg';
  static const String list = 'list.svg';
  static const String load_action_floppy = 'load_action_floppy.svg';
  static const String lock_key = 'lock_key.svg';
  static const String lock = 'lock.svg';
  static const String locked_book = 'locked_book.svg';
  static const String locked_window = 'locked_window.svg';
  static const String log_denied = 'log_denied.svg';
  static const String log_in = 'log_in.svg';
  static const String log_out = 'log_out.svg';
  static const String long_arrow_down_left = 'long_arrow_down_left.svg';
  static const String long_arrow_down_right = 'long_arrow_down_right.svg';
  static const String long_arrow_left_down = 'long_arrow_left_down.svg';
  static const String long_arrow_left_up = 'long_arrow_left_up.svg';
  static const String long_arrow_right_down = 'long_arrow_right_down.svg';
  static const String long_arrow_right_up_1 = 'long_arrow_right_up_1.svg';
  static const String long_arrow_right_up = 'long_arrow_right_up.svg';
  static const String long_arrow_up_left = 'long_arrow_up_left.svg';
  static const String long_arrow_up_right = 'long_arrow_up_right.svg';
  static const String lot_of_cash = 'lot_of_cash.svg';
  static const String mac_control_key = 'mac_control_key.svg';
  static const String mac_dock = 'mac_dock.svg';
  static const String mac_option_key = 'mac_option_key.svg';
  static const String mac_os_window = 'mac_os_window.svg';
  static const String magnet_energy = 'magnet_energy.svg';
  static const String magnet = 'magnet.svg';
  static const String mail_opened = 'mail_opened.svg';
  static const String mail = 'mail.svg';
  static const String male = 'male.svg';
  static const String map_issue = 'map_issue.svg';
  static const String map = 'map.svg';
  static const String maps_arrow_diagonal = 'maps_arrow_diagonal.svg';
  static const String maps_arrow_issue = 'maps_arrow_issue.svg';
  static const String maps_arrow = 'maps_arrow.svg';
  static const String maps_go_straight = 'maps_go_straight.svg';
  static const String maps_turn_back = 'maps_turn_back.svg';
  static const String maps_turn_left = 'maps_turn_left.svg';
  static const String maps_turn_right = 'maps_turn_right.svg';
  static const String mask_square = 'mask_square.svg';
  static const String math_book = 'math_book.svg';
  static const String maximize = 'maximize.svg';
  static const String medal = 'medal.svg';
  static const String media_image_folder = 'media_image_folder.svg';
  static const String media_image_list = 'media_image_list.svg';
  static const String media_image = 'media_image.svg';
  static const String media_video_folder = 'media_video_folder.svg';
  static const String media_video_list = 'media_video_list.svg';
  static const String media_video = 'media_video.svg';
  static const String medium = 'medium.svg';
  static const String megaphone = 'megaphone.svg';
  static const String menu_scale = 'menu_scale.svg';
  static const String menu = 'menu.svg';
  static const String message_alert = 'message_alert.svg';
  static const String message_text = 'message_text.svg';
  static const String message = 'message.svg';
  static const String metro = 'metro.svg';
  static const String mic_add = 'mic_add.svg';
  static const String mic_check = 'mic_check.svg';
  static const String mic_mute = 'mic_mute.svg';
  static const String mic_remove = 'mic_remove.svg';
  static const String mic_speaking = 'mic_speaking.svg';
  static const String mic_warning = 'mic_warning.svg';
  static const String mic = 'mic.svg';
  static const String minus_1 = 'minus_1.svg';
  static const String minus_hexagon = 'minus_hexagon.svg';
  static const String minus_pin_alt = 'minus_pin_alt.svg';
  static const String minus_square = 'minus_square.svg';
  static const String minus = 'minus.svg';
  static const String missing_font = 'missing_font.svg';
  static const String modern_tv_4k = 'modern_tv_4k.svg';
  static const String modern_tv = 'modern_tv.svg';
  static const String money_square = 'money_square.svg';
  static const String moon_sat = 'moon_sat.svg';
  static const String more_horiz_circled_outline =
      'more_horiz_circled_outline.svg';
  static const String more_horiz = 'more_horiz.svg';
  static const String more_vert_circled_outline =
      'more_vert_circled_outline.svg';
  static const String more_vert = 'more_vert.svg';
  static const String motorcycle = 'motorcycle.svg';
  static const String mouse_button_left = 'mouse_button_left.svg';
  static const String mouse_button_right = 'mouse_button_right.svg';
  static const String mouse_scroll_wheel = 'mouse_scroll_wheel.svg';
  static const String move_down = 'move_down.svg';
  static const String move_left = 'move_left.svg';
  static const String move_right = 'move_right.svg';
  static const String move_ruler = 'move_ruler.svg';
  static const String move_up = 'move_up.svg';
  static const String movie = 'movie.svg';
  static const String multi_bubble = 'multi_bubble.svg';
  static const String multi_mac_os_window = 'multi_mac_os_window.svg';
  static const String multi_window = 'multi_window.svg';
  static const String multiple_pages_add = 'multiple_pages_add.svg';
  static const String multiple_pages_delete = 'multiple_pages_delete.svg';
  static const String multiple_pages_empty = 'multiple_pages_empty.svg';
  static const String multiple_pages_remove = 'multiple_pages_remove.svg';
  static const String multiple_pages = 'multiple_pages.svg';
  static const String music_1_add = 'music_1_add.svg';
  static const String music_1 = 'music_1.svg';
  static const String music_2_add = 'music_2_add.svg';
  static const String music_2 = 'music_2.svg';
  static const String nav_arrow_down = 'nav_arrow_down.svg';
  static const String nav_arrow_left = 'nav_arrow_left.svg';
  static const String nav_arrow_right = 'nav_arrow_right.svg';
  static const String nav_arrow_up = 'nav_arrow_up.svg';
  static const String navigator_alt = 'navigator_alt.svg';
  static const String navigator = 'navigator.svg';
  static const String network_alt = 'network_alt.svg';
  static const String network_left = 'network_left.svg';
  static const String network_right = 'network_right.svg';
  static const String network = 'network.svg';
  static const String new_tab = 'new_tab.svg';
  static const String nintendo_switch = 'nintendo_switch.svg';
  static const String nitrogen = 'nitrogen.svg';
  static const String no_access_window = 'no_access_window.svg';
  static const String no_battery = 'no_battery.svg';
  static const String no_coin = 'no_coin.svg';
  static const String no_credit_card = 'no_credit_card.svg';
  static const String no_lock = 'no_lock.svg';
  static const String no_smoking_circled = 'no_smoking_circled.svg';
  static const String no_smoking = 'no_smoking.svg';
  static const String notes = 'notes.svg';
  static const String numbered_list_left = 'numbered_list_left.svg';
  static const String numbered_list_right = 'numbered_list_right.svg';
  static const String octagon = 'octagon.svg';
  static const String off_rounded = 'off_rounded.svg';
  static const String oil_industry = 'oil_industry.svg';
  static const String on_rounded = 'on_rounded.svg';
  static const String one_finger_select_hand_gesture =
      'one_finger_select_hand_gesture.svg';
  static const String one_point_circle = 'one_point_circle.svg';
  static const String open_book = 'open_book.svg';
  static const String open_in_browser = 'open_in_browser.svg';
  static const String open_in_window = 'open_in_window.svg';
  static const String open_new_window = 'open_new_window.svg';
  static const String open_select_hand_gesture = 'open_select_hand_gesture.svg';
  static const String open_vpn = 'open_vpn.svg';
  static const String orange_half = 'orange_half.svg';
  static const String orange_slice_alt = 'orange_slice_alt.svg';
  static const String orange_slice = 'orange_slice.svg';
  static const String orthogonal_view = 'orthogonal_view.svg';
  static const String oxygen = 'oxygen.svg';
  static const String package_lock = 'package_lock.svg';
  static const String package_ = 'package.svg';
  static const String packages = 'packages.svg';
  static const String pacman = 'pacman.svg';
  static const String page_edit = 'page_edit.svg';
  static const String page_flip = 'page_flip.svg';
  static const String page_search = 'page_search.svg';
  static const String page_star = 'page_star.svg';
  static const String page = 'page.svg';
  static const String palette = 'palette.svg';
  static const String panorama_enlarge = 'panorama_enlarge.svg';
  static const String panorama_reduce = 'panorama_reduce.svg';
  static const String pants_alt = 'pants_alt.svg';
  static const String pants = 'pants.svg';
  static const String parking = 'parking.svg';
  static const String password_cursor = 'password_cursor.svg';
  static const String password_error = 'password_error.svg';
  static const String password_pass = 'password_pass.svg';
  static const String paste_clipboard = 'paste_clipboard.svg';
  static const String pause_outline = 'pause_outline.svg';
  static const String pause_window = 'pause_window.svg';
  static const String pc_check = 'pc_check.svg';
  static const String pc_firewall = 'pc_firewall.svg';
  static const String pc_mouse = 'pc_mouse.svg';
  static const String pc_no_entry = 'pc_no_entry.svg';
  static const String pc_warning = 'pc_warning.svg';
  static const String peace_hand = 'peace_hand.svg';
  static const String pen_connect_bluetooth = 'pen_connect_bluetooth.svg';
  static const String pen_connect_wifi = 'pen_connect_wifi.svg';
  static const String pen_tablet_connect_usb = 'pen_tablet_connect_usb.svg';
  static const String pen_tablet_connect_wifi = 'pen_tablet_connect_wifi.svg';
  static const String pen_tablet = 'pen_tablet.svg';
  static const String pentagon = 'pentagon.svg';
  static const String people_rounded = 'people_rounded.svg';
  static const String percentage_round = 'percentage_round.svg';
  static const String percentage_square = 'percentage_square.svg';
  static const String percentage = 'percentage.svg';
  static const String perspective_view = 'perspective_view.svg';
  static const String pharmacy_circled_cross = 'pharmacy_circled_cross.svg';
  static const String pharmacy_squared_cross = 'pharmacy_squared_cross.svg';
  static const String phone_add = 'phone_add.svg';
  static const String phone_delete = 'phone_delete.svg';
  static const String phone_disabled = 'phone_disabled.svg';
  static const String phone_income = 'phone_income.svg';
  static const String phone_outcome = 'phone_outcome.svg';
  static const String phone_paused = 'phone_paused.svg';
  static const String phone_remove = 'phone_remove.svg';
  static const String phone = 'phone.svg';
  static const String piggy_bank = 'piggy_bank.svg';
  static const String pin_alt = 'pin_alt.svg';
  static const String pin = 'pin.svg';
  static const String pinterest = 'pinterest.svg';
  static const String pizza_slice = 'pizza_slice.svg';
  static const String planet_alt = 'planet_alt.svg';
  static const String planet_sat = 'planet_sat.svg';
  static const String planet = 'planet.svg';
  static const String play_outline = 'play_outline.svg';
  static const String playlist_add = 'playlist_add.svg';
  static const String playlist_play = 'playlist_play.svg';
  static const String playlist = 'playlist.svg';
  static const String playstation_gamepad = 'playstation_gamepad.svg';
  static const String plug_type_a = 'plug_type_a.svg';
  static const String plug_type_c = 'plug_type_c.svg';
  static const String plug_type_g = 'plug_type_g.svg';
  static const String plug_type_l = 'plug_type_l.svg';
  static const String plus = 'plus.svg';
  static const String pocket = 'pocket.svg';
  static const String podcast = 'podcast.svg';
  static const String pokeball = 'pokeball.svg';
  static const String position_align = 'position_align.svg';
  static const String position = 'position.svg';
  static const String potion = 'potion.svg';
  static const String pound = 'pound.svg';
  static const String precision_tool = 'precision_tool.svg';
  static const String printer_alt = 'printer_alt.svg';
  static const String printer = 'printer.svg';
  static const String printing_page = 'printing_page.svg';
  static const String priority_down = 'priority_down.svg';
  static const String priority_up = 'priority_up.svg';
  static const String private_wifi = 'private_wifi.svg';
  static const String profile_circled = 'profile_circled.svg';
  static const String prohibition = 'prohibition.svg';
  static const String puzzle = 'puzzle.svg';
  static const String qr_code = 'qr_code.svg';
  static const String question_mark_circle = 'question_mark_circle.svg';
  static const String question_mark = 'question_mark.svg';
  static const String question_square_outline = 'question_square_outline.svg';
  static const String quote_message = 'quote_message.svg';
  static const String quote = 'quote.svg';
  static const String rain = 'rain.svg';
  static const String receive_dollars = 'receive_dollars.svg';
  static const String receive_euros = 'receive_euros.svg';
  static const String receive_pounds = 'receive_pounds.svg';
  static const String receive_yens = 'receive_yens.svg';
  static const String redo_action = 'redo_action.svg';
  static const String redo_circle = 'redo_circle.svg';
  static const String redo = 'redo.svg';
  static const String reduce_round_arrow = 'reduce_round_arrow.svg';
  static const String reduce = 'reduce.svg';
  static const String refresh_circular = 'refresh_circular.svg';
  static const String refresh_double = 'refresh_double.svg';
  static const String refresh = 'refresh.svg';
  static const String reload_window = 'reload_window.svg';
  static const String reminder_hand_gesture = 'reminder_hand_gesture.svg';
  static const String remove_database_script = 'remove_database_script.svg';
  static const String remove_empty = 'remove_empty.svg';
  static const String remove_folder = 'remove_folder.svg';
  static const String remove_frame = 'remove_frame.svg';
  static const String remove_from_cart = 'remove_from_cart.svg';
  static const String remove_keyframe_alt = 'remove_keyframe_alt.svg';
  static const String remove_keyframe = 'remove_keyframe.svg';
  static const String remove_keyframes = 'remove_keyframes.svg';
  static const String remove_media_image = 'remove_media_image.svg';
  static const String remove_media_video = 'remove_media_video.svg';
  static const String remove_page = 'remove_page.svg';
  static const String remove_pin_alt = 'remove_pin_alt.svg';
  static const String remove_selection = 'remove_selection.svg';
  static const String remove_square = 'remove_square.svg';
  static const String remove_user = 'remove_user.svg';
  static const String repeat_once = 'repeat_once.svg';
  static const String repeat = 'repeat.svg';
  static const String report_columns = 'report_columns.svg';
  static const String reports = 'reports.svg';
  static const String restart = 'restart.svg';
  static const String rewind_outline = 'rewind_outline.svg';
  static const String rhombus = 'rhombus.svg';
  static const String right_round_arrow = 'right_round_arrow.svg';
  static const String rings = 'rings.svg';
  static const String rook = 'rook.svg';
  static const String rotate_camera_left = 'rotate_camera_left.svg';
  static const String rotate_camera_right = 'rotate_camera_right.svg';
  static const String round_flask = 'round_flask.svg';
  static const String rss_feed_squared = 'rss_feed_squared.svg';
  static const String rss_feed = 'rss_feed.svg';
  static const String ruler_add = 'ruler_add.svg';
  static const String ruler_combine = 'ruler_combine.svg';
  static const String ruler_remove = 'ruler_remove.svg';
  static const String ruler = 'ruler.svg';
  static const String running = 'running.svg';
  static const String safari = 'safari.svg';
  static const String sandals = 'sandals.svg';
  static const String save_action_floppy = 'save_action_floppy.svg';
  static const String save_floppy_disk = 'save_floppy_disk.svg';
  static const String scale_frame_enlarge = 'scale_frame_enlarge.svg';
  static const String scale_frame_reduce = 'scale_frame_reduce.svg';
  static const String scan_barcode = 'scan_barcode.svg';
  static const String scan_qr_code = 'scan_qr_code.svg';
  static const String scanning = 'scanning.svg';
  static const String scarf = 'scarf.svg';
  static const String scissor_alt = 'scissor_alt.svg';
  static const String scissor = 'scissor.svg';
  static const String sea_and_sun = 'sea_and_sun.svg';
  static const String sea_waves = 'sea_waves.svg';
  static const String search_engine = 'search_engine.svg';
  static const String search_font = 'search_font.svg';
  static const String search_window = 'search_window.svg';
  static const String search = 'search.svg';
  static const String secure_window = 'secure_window.svg';
  static const String security_pass = 'security_pass.svg';
  static const String select_window = 'select_window.svg';
  static const String selection = 'selection.svg';
  static const String selective_tool = 'selective_tool.svg';
  static const String send_dollars = 'send_dollars.svg';
  static const String send_euros = 'send_euros.svg';
  static const String send_pounds = 'send_pounds.svg';
  static const String send_yens = 'send_yens.svg';
  static const String server_connection = 'server_connection.svg';
  static const String server = 'server.svg';
  static const String settings_cloud = 'settings_cloud.svg';
  static const String settings_profiles = 'settings_profiles.svg';
  static const String settings = 'settings.svg';
  static const String share_android = 'share_android.svg';
  static const String share_ios = 'share_ios.svg';
  static const String shield_add = 'shield_add.svg';
  static const String shield_alert = 'shield_alert.svg';
  static const String shield_alt = 'shield_alt.svg';
  static const String shield_broken = 'shield_broken.svg';
  static const String shield_check = 'shield_check.svg';
  static const String shield_cross = 'shield_cross.svg';
  static const String shield_download = 'shield_download.svg';
  static const String shield_eye = 'shield_eye.svg';
  static const String shield_loading = 'shield_loading.svg';
  static const String shield_minus = 'shield_minus.svg';
  static const String shield_question = 'shield_question.svg';
  static const String shield_search = 'shield_search.svg';
  static const String shield_upload = 'shield_upload.svg';
  static const String shield = 'shield.svg';
  static const String shop_alt = 'shop_alt.svg';
  static const String shop = 'shop.svg';
  static const String shopping_bag_add = 'shopping_bag_add.svg';
  static const String shopping_bag_alt = 'shopping_bag_alt.svg';
  static const String shopping_bag_arrow_down = 'shopping_bag_arrow_down.svg';
  static const String shopping_bag_arrow_up = 'shopping_bag_arrow_up.svg';
  static const String shopping_bag_check = 'shopping_bag_check.svg';
  static const String shopping_bag_issue = 'shopping_bag_issue.svg';
  static const String shopping_bag_remove = 'shopping_bag_remove.svg';
  static const String shopping_bag = 'shopping_bag.svg';
  static const String shopping_code_check = 'shopping_code_check.svg';
  static const String shopping_code_error = 'shopping_code_error.svg';
  static const String shopping_code = 'shopping_code.svg';
  static const String short_pants_alt = 'short_pants_alt.svg';
  static const String short_pants = 'short_pants.svg';
  static const String shuffle = 'shuffle.svg';
  static const String sidebar_collapse = 'sidebar_collapse.svg';
  static const String sidebar_expand = 'sidebar_expand.svg';
  static const String sigma_function = 'sigma_function.svg';
  static const String simple_cart = 'simple_cart.svg';
  static const String single_tap_gesture = 'single_tap_gesture.svg';
  static const String skateboard = 'skateboard.svg';
  static const String skateboarding = 'skateboarding.svg';
  static const String skip_next_outline = 'skip_next_outline.svg';
  static const String skip_prev_outline = 'skip_prev_outline.svg';
  static const String small_shop_alt = 'small_shop_alt.svg';
  static const String small_shop = 'small_shop.svg';
  static const String smartphone_device = 'smartphone_device.svg';
  static const String smoking = 'smoking.svg';
  static const String snapchat = 'snapchat.svg';
  static const String snow_flake = 'snow_flake.svg';
  static const String snow = 'snow.svg';
  static const String soap = 'soap.svg';
  static const String soccer_ball = 'soccer_ball.svg';
  static const String sort_down = 'sort_down.svg';
  static const String sort_up = 'sort_up.svg';
  static const String sound_high = 'sound_high.svg';
  static const String sound_low = 'sound_low.svg';
  static const String sound_min = 'sound_min.svg';
  static const String sound_off = 'sound_off.svg';
  static const String spades = 'spades.svg';
  static const String sphere = 'sphere.svg';
  static const String spiral = 'spiral.svg';
  static const String spock_hand_gesture = 'spock_hand_gesture.svg';
  static const String square = 'square.svg';
  static const String stackoverflow = 'stackoverflow.svg';
  static const String star_dashed = 'star_dashed.svg';
  static const String star_half_dashed = 'star_half_dashed.svg';
  static const String star_outline = 'star_outline.svg';
  static const String stat_down = 'stat_down.svg';
  static const String stat_up = 'stat_up.svg';
  static const String stats_report = 'stats_report.svg';
  static const String stats_square_down = 'stats_square_down.svg';
  static const String stats_square_up = 'stats_square_up.svg';
  static const String stretching = 'stretching.svg';
  static const String stroller = 'stroller.svg';
  static const String style_border = 'style_border.svg';
  static const String substract = 'substract.svg';
  static const String suggestion = 'suggestion.svg';
  static const String sun_light = 'sun_light.svg';
  static const String swimming = 'swimming.svg';
  static const String swipe_down_gesture = 'swipe_down_gesture.svg';
  static const String swipe_left_gesture = 'swipe_left_gesture.svg';
  static const String swipe_right_gesture = 'swipe_right_gesture.svg';
  static const String swipe_two_fingers_down_gesture =
      'swipe_two_fingers_down_gesture.svg';
  static const String swipe_two_fingers_left_gesture =
      'swipe_two_fingers_left_gesture.svg';
  static const String swipe_two_fingers_right_gesture =
      'swipe_two_fingers_right_gesture.svg';
  static const String swipe_two_fingers_up_gesture =
      'swipe_two_fingers_up_gesture.svg';
  static const String swipe_up_gesture = 'swipe_up_gesture.svg';
  static const String switch_off_outline = 'switch_off_outline.svg';
  static const String switch_on_outline = 'switch_on_outline.svg';
  static const String system_restart = 'system_restart.svg';
  static const String system_shut = 'system_shut.svg';
  static const String table_2_columns = 'table_2_columns.svg';
  static const String table_rows = 'table_rows.svg';
  static const String table = 'table.svg';
  static const String task_list = 'task_list.svg';
  static const String telegram_circled = 'telegram_circled.svg';
  static const String telegram = 'telegram.svg';
  static const String tennis_ball_alt = 'tennis_ball_alt.svg';
  static const String tennis_ball = 'tennis_ball.svg';
  static const String terminal_outline = 'terminal_outline.svg';
  static const String terminal_simple = 'terminal_simple.svg';
  static const String test_tube = 'test_tube.svg';
  static const String text_alt = 'text_alt.svg';
  static const String text_size = 'text_size.svg';
  static const String text = 'text.svg';
  static const String three_points_circle = 'three_points_circle.svg';
  static const String three_stars = 'three_stars.svg';
  static const String thumbs_down = 'thumbs_down.svg';
  static const String thumbs_up = 'thumbs_up.svg';
  static const String thunderstorm = 'thunderstorm.svg';
  static const String tiktok = 'tiktok.svg';
  static const String timer_off = 'timer_off.svg';
  static const String timer = 'timer.svg';
  static const String tournament = 'tournament.svg';
  static const String tower_check = 'tower_check.svg';
  static const String tower_no_access = 'tower_no_access.svg';
  static const String tower_warning = 'tower_warning.svg';
  static const String tower = 'tower.svg';
  static const String trademark = 'trademark.svg';
  static const String train_outline = 'train_outline.svg';
  static const String tram = 'tram.svg';
  static const String transition_bottom = 'transition_bottom.svg';
  static const String transition_left = 'transition_left.svg';
  static const String transition_right = 'transition_right.svg';
  static const String transition_top = 'transition_top.svg';
  static const String translate = 'translate.svg';
  static const String trash = 'trash.svg';
  static const String treadmill = 'treadmill.svg';
  static const String trekking = 'trekking.svg';
  static const String trello = 'trello.svg';
  static const String triangle_flag_circle = 'triangle_flag_circle.svg';
  static const String triangle_flag_full = 'triangle_flag_full.svg';
  static const String triangle_flag = 'triangle_flag.svg';
  static const String triangle = 'triangle.svg';
  static const String trophy = 'trophy.svg';
  static const String truck_length = 'truck_length.svg';
  static const String truck = 'truck.svg';
  static const String tunnel = 'tunnel.svg';
  static const String tv_fix = 'tv_fix.svg';
  static const String tv_issue = 'tv_issue.svg';
  static const String tv = 'tv.svg';
  static const String twitter_verified_badge = 'twitter_verified_badge.svg';
  static const String twitter = 'twitter.svg';
  static const String two_points_circle = 'two_points_circle.svg';
  static const String type = 'type.svg';
  static const String umbrella_full = 'umbrella_full.svg';
  static const String underline_square_outline = 'underline_square_outline.svg';
  static const String underline = 'underline.svg';
  static const String undo_action = 'undo_action.svg';
  static const String undo_circle = 'undo_circle.svg';
  static const String undo = 'undo.svg';
  static const String union_alt = 'union_alt.svg';
  static const String union_horiz_alt = 'union_horiz_alt.svg';
  static const String union = 'union.svg';
  static const String unity_5 = 'unity_5.svg';
  static const String unity = 'unity.svg';
  static const String up_round_arrow = 'up_round_arrow.svg';
  static const String upload_data_window = 'upload_data_window.svg';
  static const String upload_square_outline = 'upload_square_outline.svg';
  static const String upload = 'upload.svg';
  static const String usb = 'usb.svg';
  static const String user_bag = 'user_bag.svg';
  static const String user_cart = 'user_cart.svg';
  static const String user_circle_alt = 'user_circle_alt.svg';
  static const String user_scan = 'user_scan.svg';
  static const String user_square_alt = 'user_square_alt.svg';
  static const String user = 'user.svg';
  static const String verified_badge = 'verified_badge.svg';
  static const String verified_user = 'verified_user.svg';
  static const String video_camera_off = 'video_camera_off.svg';
  static const String video_camera = 'video_camera.svg';
  static const String view_columns_2 = 'view_columns_2.svg';
  static const String view_columns_3 = 'view_columns_3.svg';
  static const String view_grid = 'view_grid.svg';
  static const String view_structure_down = 'view_structure_down.svg';
  static const String view_structure_up = 'view_structure_up.svg';
  static const String voice_circled_lock = 'voice_circled_lock.svg';
  static const String voice_circled = 'voice_circled.svg';
  static const String voice_error = 'voice_error.svg';
  static const String voice_ok = 'voice_ok.svg';
  static const String voice_phone = 'voice_phone.svg';
  static const String voice_scan = 'voice_scan.svg';
  static const String voice_squared = 'voice_squared.svg';
  static const String voice = 'voice.svg';
  static const String vr_symbol = 'vr_symbol.svg';
  static const String waist = 'waist.svg';
  static const String walking = 'walking.svg';
  static const String wallet = 'wallet.svg';
  static const String warning_circled_outline = 'warning_circled_outline.svg';
  static const String warning_square_outline = 'warning_square_outline.svg';
  static const String warning_triangle_outline = 'warning_triangle_outline.svg';
  static const String warning_window = 'warning_window.svg';
  static const String wash = 'wash.svg';
  static const String washing_machine = 'washing_machine.svg';
  static const String web_window_close = 'web_window_close.svg';
  static const String web_window_energy_consumption =
      'web_window_energy_consumption.svg';
  static const String web_window = 'web_window.svg';
  static const String weight_alt = 'weight_alt.svg';
  static const String weight = 'weight.svg';
  static const String white_flag = 'white_flag.svg';
  static const String wifi_error = 'wifi_error.svg';
  static const String wifi_issue = 'wifi_issue.svg';
  static const String wifi_off = 'wifi_off.svg';
  static const String wifi_rounded = 'wifi_rounded.svg';
  static const String wifi_signal_none = 'wifi_signal_none.svg';
  static const String wifi = 'wifi.svg';
  static const String wind = 'wind.svg';
  static const String windows = 'windows.svg';
  static const String wrap_text = 'wrap_text.svg';
  static const String wristwatch = 'wristwatch.svg';
  static const String www = 'www.svg';
  static const String xbox_a = 'xbox_a.svg';
  static const String xbox_b = 'xbox_b.svg';
  static const String xbox_x = 'xbox_x.svg';
  static const String xbox_y = 'xbox_y.svg';
  static const String xray_view = 'xray_view.svg';
  static const String yen_square = 'yen_square.svg';
  static const String yen = 'yen.svg';
  static const String yoga = 'yoga.svg';
  static const String youtube = 'youtube.svg';
  static const String zoom_in = 'zoom_in.svg';
  static const String zoom_out = 'zoom_out.svg';
}
